<?php 

namespace Management\Controllers;

use Management\Services\DashboardDataService;
use Management\Services\SetFilialSelecionada;
use Zeedhi\Framework\DTO;
use Doctrine\ORM\EntityManager;

class DashboardDataController {    

    protected $DashboardDataService;

    public function __construct (DashboardDataService $ManageDashboardService) {
        $this->DashboardDataService = $ManageDashboardService;
    }
    
    private function returnRequestFilter($request) {
        $arr = array();
        foreach ($request->getFilterCriteria()->getConditions() as $condition) {
            $arr[ $condition['columnName'] ] = $condition['value'];  
        }
        return $arr;
    }
    
    public function syncDashboardData (DTO\Request\Filter $request, DTO\Response $response) {
        $response = $this->DashboardDataService->syncDashboardData();
        return $response;
    }
    
    
    public function getDashboardData (DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->returnRequestFilter($request);
    
        $diasAnterioes = $conditions['DIASANTERIORES'];
        
        if(empty($diasAnterioes) || $diasAnterioes >= 0 ) {
            $diasAnterioes = 0;
            $dataAtual = date ('d/m/y');
        } else 
            $dataAtual = $conditions['DATAREGISTRO'];
        
        $dataBusca = $dataAtual;
        
        $params = array(
			':CDOPERADOR'	=>	$conditions['CDOPERADOR'],
			':NRORG'		=>	$conditions['NRORG'],
			':DATA'         =>  $dataBusca,
			':MENOSDIAS'    => $diasAnterioes
		);
		
		if(array_key_exists('CDFILIAL', $conditions) ) {
		    $params[':CDFILIAL'] = $conditions['CDFILIAL'];
		}
		
		$dados = $this->getConjuntoDados($params);
		
        return $this->montaResponse($dados, $response);
    }
    
    private function getConjuntoDados ($params) {
        $executar = true;
        
        $totalVendaFilial = $this->DashboardDataService->getTotalVendaFilial($params);
        $status = array('STATUS' => $totalVendaFilial->getStatus(),
                        'DATA'   => $totalVendaFilial->getData());
        
        if($status['STATUS'] == 300 || $status['STATUS'] == 200) {
            $params[':DATA'] = $totalVendaFilial->getData();
            $totalVendaFilial = $totalVendaFilial->getDados();
        } else 
            $executar = false;
        
        if($executar) {
            $retorno = $this->getEveryDashboardDataAtOnce($params);
            $retorno['status'] = $status;
            $retorno['getTotalVendaFilial'] = $totalVendaFilial;
        } else {
             $retorno = array(
                'status' => $status
            );
        }
        return $retorno;
    }
    
    private function getEveryDashboardDataAtOnce($params) {
        if(array_key_exists(':CDFILIAL', $params)) {
            $vendasConcluidas = $this->DashboardDataService->getQuantidadeVendasConcluidasByFilial($params);
            $vendasCanceladas = $this->DashboardDataService->getQuantidadeVendasCanceladasByFilial($params);
        } else {
            $vendasConcluidas = $this->DashboardDataService->getQuantidadeVendasConcluidas($params);
            $vendasCanceladas = $this->DashboardDataService->getQuantidadeVendasCanceladas($params);
        }
        
        $totalVenda = $this->DashboardDataService->getTotalVenda($params);
        $vendaPorHora = $this->DashboardDataService->getVendaHora($params);
        $ticketMedio = $this->DashboardDataService->getTicketMedio($params);
        $ticketMedioFilial = $this->DashboardDataService->getTicketMedioFilial($params);
        $vendaModalidade = $this->DashboardDataService->getVendaModalidade($params);
        $vendaModalidadeFilial = $this->DashboardDataService->getVendaModalidadeFilial($params);
        
        
        $retorno = array(
            'getQuantidadeVendasConcluidas'     => $vendasConcluidas,
            'getQuantidadeVendasCanceladas'     => $vendasCanceladas,
            'getTotalVenda'                     => $totalVenda,
            'getTicketMedio'                    => $ticketMedio,
            'getTicketMedioFilial'              => $ticketMedioFilial,
            'getVendaModalidade'                => $vendaModalidade,
            'getVendaModalidadeFilial'          => $vendaModalidadeFilial,
            'getVendaHora'                      => $vendaPorHora
        );
        
        return $retorno;
    }
    
    private function montaResponse ($dados, $response) {
        $nomes = array_keys($dados);
        
        foreach ($nomes as $nomeDataSet) {
            if($dados[$nomeDataSet])
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet($nomeDataSet, $dados[$nomeDataSet]));
        }
        
        return $response;
    }
}